==> react-native-deuna-library-0.6.15.tgz: package/src/components/ConfirmarTransaccion.tsx <==
import React, { useEffect } from 'react';
import { View, Text, StyleSheet, Pressable } from 'react-native';
import { useRoute } from '@react-navigation/native';
import PubSub  from 'pubsub-js';
import numerosregistrados from '../datos/numerosregistrados.json';
export const ConfirmarTransaccion = () => {
  const route = useRoute<any>();
  const [datos, setDatos] = React.useState<any>({});
  const [ValorPagar, setValorPagar] = React.useState<number>(0);

  useEffect(() => {
    numerosregistrados.forEach((item: any) => {
      if (item.number === route.params.number) {
        setDatos(item);
      }
    });
    setValorPagar(route.params.valorPagar);
  }, [datos, route]);
  return (
    <View style={styles.container}>
      
      <Text style={styles.textoCuenta}>
        Ha pagado {ValorPagar ? ValorPagar.toFixed(2) : 0.0}$ a{' '}
        {datos && datos.name ? datos.name.toUpperCase() : ''}
      </Text>
      <View style={styles.info}>
        <View style={styles.seccion}>
          <View style={styles.subsecciones}>
            <Text> Valor: </Text>
            <Text>${ValorPagar}</Text>
          </View>
        </View>
        <View style={styles.seccion}>
          <View style={styles.subsecciones}>
            <Text> De: </Text>
            <Text>{datos.name}</Text>
          </View>
          <View style={styles.subsecciones}>
            <Text> Desde la cuenta: </Text>
            <Text>{datos.account}</Text>
          </View>
          <View style={styles.subsecciones}>
            <Text>A la cuenta: </Text>
            <Text>2238*****2232</Text>
          </View>
          <View style={styles.subsecciones}>
            <Text> Telefono </Text>
            <Text>0996730142</Text>
          </View>
        </View>
        <View style={styles.seccion}>
          <View style={styles.subsecciones}>
            <Text> Fecha de pago: </Text>
            <Text>11/12/2022/10:00</Text>
          </View>
          <View style={styles.subsecciones}>
            <Text> Nro Comprobante: </Text>
            <Text>238798723</Text>
          </View>
        </View>
        <View style={styles.seccion}>
          <Text style={styles.comprobante}>
            Compartir Comprobante
          </Text>
        </View>
      </View>
      <Pressable style={styles.Btn} onPress={()=>{PubSub.publish('confirmarTran', {name: datos.name, otro: ValorPagar} )}}>
        <Text>Continuar</Text>  
      </Pressable>
    </View>
  );
};
const styles = StyleSheet.create({
  textoCuenta: {
    fontWeight: 'bold',
    fontSize: 20,
    width: 200,
    textAlign: 'center',
  },
  container: {
    padding: 20,
    flex: 1,
    alignItems: 'center',
    backgroundColor: '#FFFFFF',
  },
  icono: {
    fontSize: 30,
    color: '#422d4e',
    padding: 15,
  },
  containerIcono: {
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
  },
  info: {
    marginTop: 20,
    borderTopColor: 'black',
    borderTopWidth: 1,
    backgroundColor: '#ececec',
    width: '100%',
  },
  seccion: {
    borderTopColor: 'black',
    borderTopWidth: 0.3,
    backgroundColor: '#efefef',
    width: '100%',
  },
  subsecciones: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    paddingTop: 5,
    paddingBottom: 5,
    paddingLeft: 15,
    paddingRight: 15,
  },
  comprobante: {
    padding: 20,
    textAlign: 'center',
    fontWeight: 'bold',
  },
  iconoShare: {
    fontSize: 25,
  },
  Btn: {
    width: '100%',
    backgroundColor: '#FFDD00',
    padding: 15,
    marginTop: 35,
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
  },
});

==> react-native-deuna-library-0.9.22.tgz: package/src/components/ConfirmarTransaccion.tsx <==
import React from 'react';
import { View, Text, StyleSheet, Pressable } from 'react-native';
import { useRoute} from '@react-navigation/native';
export const ConfirmarTransaccion = () => {
  const route = useRoute<any>();
  const dataTransaccion=route.params.dataTransaccion
  const amount=dataTransaccion.datosDebtor.data.transaction.amount
  console.log(amount)
  const debtor=dataTransaccion.datosDebtor.data.debtor
  const creditor=dataTransaccion.datosDebtor.data.creditor
  let dataConvert:string=dataTransaccion.datosDocument.data.accountingDate
  const dataConvert2:string=dataConvert.substring(0,2)+'/'+dataConvert.substring(2,4)+'/'+dataConvert.substring(4,8)
  console.log(dataTransaccion)
  return (
    <View style={styles.container}>
      
      <Text style={styles.textoCuenta}>
        Ha pagado {amount? parseFloat(amount).toFixed(2): 0.0}$ a{' '}
        {debtor && debtor.customer.fullName ? debtor.customer.fullName.toUpperCase() : ''}
      </Text>
      <View style={styles.info}>
        <View style={styles.seccion}>
          <View style={styles.subsecciones}>
            <Text> Valor: </Text>
            <Text>{amount}</Text>
          </View>
        </View>
        <View style={styles.seccion}>
          <View style={styles.subsecciones}>
            <Text> De: </Text>
            <Text>{creditor.customer.fullName}</Text>
          </View>
          <View style={styles.subsecciones}>
            <Text> Desde la cuenta: </Text>
            <Text>{debtor.account.accountId}</Text>
          </View>
          <View style={styles.subsecciones}>
            <Text>A la cuenta: </Text>
            <Text>{debtor.account.accountId}</Text>
          </View>
          <View style={styles.subsecciones}>
            <Text> Telefono </Text>
            <Text>0996730142</Text>
          </View>
        </View>
        <View style={styles.seccion}>
          <View style={styles.subsecciones}>
            <Text> Fecha de pago: </Text>
            <Text>{dataConvert2}</Text>
          </View>
          <View style={styles.subsecciones}>
            <Text> Nro Comprobante: </Text>
            <Text>{dataTransaccion.datosDocument.data.businessDocumentId}</Text>
          </View>
        </View>
        <View style={styles.seccion}>
          <Text style={styles.comprobante}>
            Compartir Comprobante
          </Text>
        </View>
      </View>
      <Pressable style={styles.Btn}>
        <Text>Continuar</Text>
      </Pressable>
    </View>
  );
};
const styles = StyleSheet.create({
  textoCuenta: {
    fontWeight: 'bold',
    fontSize: 20,
    width: 200,
    textAlign: 'center',
  },
  container: {
    padding: 20,
    flex: 1,
    alignItems: 'center',
    backgroundColor: '#FFFFFF',
  },
  icono: {
    fontSize: 30,
    color: '#422d4e',
    padding: 15,
  },
  containerIcono: {
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
  },
  info: {
    marginTop: 20,
    borderTopColor: 'black',
    borderTopWidth: 1,
    backgroundColor: '#ececec',
    width: '100%',
  },
  seccion: {
    borderTopColor: 'black',
    borderTopWidth: 0.3,
    backgroundColor: '#efefef',
    width: '100%',
  },
  subsecciones: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    paddingTop: 5,
    paddingBottom: 5,
    paddingLeft: 15,
    paddingRight: 15,
  },
  comprobante: {
    padding: 20,
    textAlign: 'center',
    fontWeight: 'bold',
  },
  iconoShare: {
    fontSize: 25,
  },
  Btn: {
    width: '100%',
    backgroundColor: '#FFDD00',
    padding: 15,
    marginTop: 35,
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
  },
});
